//+------------------------------------------------------------------+
//|                                                 FPI-3 Symbol.mq4 |
//|                                 Copyright  2006, John F. Kutzer |
//|                                     jack@wellnessbeach.com |
//+------------------------------------------------------------------+
// Implementation if Michal Kreslik's FPI indicator for Metatrader 4 (MT4)
// Read more about the concept at the link below:
//  http://kreslik.com/forums/viewtopic.php?p=2185#2185
//
// Thanks to Michal for working on this idea, and providing the information!
//
// This implementation will only handle 3 symbol sets. 
// Enter the 3 Symbols as inputs.
// Enter Long or Short as appropriate for each symbol.
// Enter the SignalLen as an integer value -- This indicator draws a moving average of the
//  FPI indicator -- This was an attempt to look for a trading signal.
// This indicator plots the FPI as a histogram, rather than a line as in Michal's work.
//  The value of the indicator is (FPI-1), so the histogram oscillates around zero, rather than 1
//  as in Michal's work.
// The indicator adjusts automatically for a regular or mini account, so you don't need to enter
//  the symbols with the 'm' for mini accounts.
//

#property  copyright "Copyright  2006, John F. Kutzer"
#property  link      "jack@wellnessbeach.com"
//---- indicator settings
#property  indicator_separate_window
#property  indicator_buffers 2
#property  indicator_color1  Blue
#property  indicator_color2  Red
#property  indicator_width1  2
//---- indicator parameters
extern string Symbol1="EURGBP";
extern string LS1="Long";
extern string Symbol2="EURJPY";
extern string LS2="Short";
extern string Symbol3="GBPJPY";
extern string LS3="Long";
extern int    SignalLen = 8;
//---- indicator buffers
double     FPIbuffer[];
double     FPI_MAbuffer[];
double     aVar=0;
double     bVar=0;
double     cVar=0;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- drawing settings
   SetIndexStyle(0,DRAW_HISTOGRAM);
   SetIndexStyle(1,DRAW_LINE);
   SetIndexDrawBegin(1,SignalLen);
   IndicatorDigits(Digits+1);
//---- indicator buffers mapping
   SetIndexBuffer(0,FPIbuffer);
   SetIndexBuffer(1,FPI_MAbuffer);
//---- name for DataWindow and indicator subwindow label
   IndicatorShortName("FPI-3 ("+LS1 +" "+ Symbol1+" - "+LS2  +" "+ Symbol2+" - "+ LS3  +" " +Symbol3+")");
   SetIndexLabel(0,"FPI-3");
   SetIndexLabel(1,"Signal");
//---- initialization done
   return(0);
  }
//+------------------------------------------------------------------+
//| FPI for 3 Symbol Groups                         |
//+------------------------------------------------------------------+
int start()
  {
//---- Adjust Symbols for Mini or Regular accounts
   double lotsize;
   lotsize = MarketInfo(Symbol1,MODE_LOTSIZE);
   if(lotsize < 100000)
      {
      Symbol1 = StringConcatenate(Symbol1,"m");
      Symbol2 = StringConcatenate(Symbol2,"m");
      Symbol3 = StringConcatenate(Symbol3,"m");
      }
   int limit;
   int counted_bars=IndicatorCounted();
//---- last counted bar will be recounted
   if(counted_bars>0) counted_bars--;
      limit=Bars-counted_bars;
//---- adjust for Long or Short position
   for(int i=0; i<limit; i++)
      {
      if(LS1 == "Long") aVar =  iClose(Symbol1,0,i);  
      else           aVar = 1/iClose(Symbol1,0,i);
      if(LS2 == "Long") bVar =  iClose(Symbol2,0,i);  
      else           bVar = 1/iClose(Symbol2,0,i);
      if(LS3 == "Long") cVar =  iClose(Symbol3,0,i);  
      else           cVar = 1/iClose(Symbol3,0,i);
      
      FPIbuffer[i] = (aVar*bVar*cVar)-1;
      }
      for(i=0; i<limit; i++)
      FPI_MAbuffer[i]=iMAOnArray(FPIbuffer,Bars,SignalLen,0,MODE_SMA,i);
//      if(FPIbuffer[0] < 1 && FPIbuffer[0] > FPIbuffer[1])
//      Alert(Symbol1 +" == " + Symbol2 + " == " + Symbol3 + " == " +DoubleToStr(aVar,Digits));
//---- done
   return(0);
  }
//+------------------------------------------------------------------+
 